pub enum LogFileRecordSource {
RedoData,
UndoData,
PageSlack,
}Expand description
Where the USN record was found within the $LogFile.
Variants
RedoData
Found in the redo data area of a log record.
UndoData
Found in the undo data area of a log record.
PageSlack
Found in slack space at the end of an RCRD page.